<?php

App::uses('EvSiteSettingsAppController', 'EvSiteSettings.Controller');

/**
 * Handles requests for site settings
 */
class SiteSettingsController extends EvSiteSettingsAppController {

	/**
	 * Defines the buttons displayed on the admin toolbar
	 */
	protected function _adminIndexToolbar() {

		$user = $this->Auth->user();
		if ($user['User']['user_group_id'] == 1) {

			return array(
				'Add New Setting' => array(
					'url' => array('action' => 'add')
				)
			);
		} else {

			return;
		}
	}

	/**
	 * Landing Page - Edit Site settings
	 *
	 * Site settings are handled differently from other models
	 * This screen is a combined index & edit
	 */
	public function admin_index() {

		$fields = array();

		$data = $this->SiteSetting->find('grouped', array(
			'order' => array(
				'SiteSettingCategory.sequence' => 'ASC',
				'SiteSetting.sequence' => 'ASC',
				'SiteSetting.array_slug' => 'ASC'
			)
		));

		// build up a field list to display the settings
		foreach ($data as $categoryName => $category) {

			foreach ($category as $setting) {

				$fields[$categoryName]['SiteSetting.' . $setting['SiteSetting']['array_slug']] = array(
					'type' => $setting['SiteSetting']['type'],
					'label' => $setting['SiteSetting']['name'] != "" ? $setting['SiteSetting']['name'] : $setting['SiteSetting']['array_slug'],
					'after' => '<span class="configure-key">Configure Key: <span>SiteSetting.' . $setting['SiteSettingCategory']['array_slug'] . '.' . $setting['SiteSetting']['array_slug'] . '</span></span>'
				);
			}
		}

		// handle a form post
		if (!empty($this->request->data)) {

			foreach ($this->request->data['SiteSetting'] as $fieldName => $value) {

				$site_setting_fields = array('value' => '"' . addslashes($value) . '"');
				$site_setting_conditions = array('SiteSetting.array_slug' => $fieldName);
				$this->SiteSetting->updateAll($site_setting_fields, $site_setting_conditions);
			}

			$this->set('settings_saved', true);
		} else {

			foreach ($data as $category) {

				foreach ($category as $setting) {

					$this->request->data['SiteSetting'][$setting['SiteSetting']['array_slug']] = $setting['SiteSetting']['value'];
				}
			}
		}

		$this->set('fields', $fields);

		$this->set('toolbar', $this->_adminIndexToolbar());

		$this->set('title_for_layout', 'Site Settings');

		$this->view = 'EvSiteSettings.SiteSettings/admin_index';
	}

	protected function _adminPopulateLookups()
	{
		$Model = $this->{$this->modelClass};
		$siteSettingCategories = $Model->SiteSettingCategory->find('list');

		$types = array(
			'string' => 'Input Box',
			'text_plain' => 'Textarea',
			'html_lite' => 'WYSIWYG Lite',
			'html' => 'WYSIWYG',
			'boolean' => 'Checkbox',
			'date' => 'Date Picker',
			'datetime' => 'Date Time Picker',
			'map' => 'Map'
		);

		$this->set(
			compact('siteSettingCategories', 'types')
		);
	}

	/**
	 * redefine to set value to plain to prevent p tags around everything
	 */
	public function _adminFormFields()
	{
		$fields = parent::_adminFormFields();

		$fields['SiteSetting.type']['type'] = 'select';
		$fields['SiteSetting.value']['type'] = 'text_plain';
		$fields['SiteSetting.sequence'] = array(
			'type' => 'string',
			'label' => 'Sequence'
		);

		return $fields;
	}

}
